@@ -1,7 +1,7 @@
 import argparse
 import sys
 
-from gettext import gettext as _
+from gettext import gettext
 
 
 class QuickArgParser(argparse.ArgumentParser):
@@ -26,7 +26,7 @@ class QuickArgParser(argparse.ArgumentParser):
         self.print_usage(sys.stderr)
         help_msg = "See '" + self.prog + " -h' for help.\n"
         args = {"message": message, "help": help_msg}
-        self.exit(2, _("\nError: %(message)s\n%(help)s") % args)
+        self.exit(2, gettext("\nError: %(message)s\n%(help)s") % args)
 
 
 class QuickHelpFormatter(argparse.HelpFormatter):
@@ -65,13 +65,23 @@ class QuickHelpFormatter(argparse.HelpFormatter):
 
 
 class ArgsAction(argparse.Action):
+    """
+    Custom action for parsing multiple key-value arguments
+
+    For example, the user invokes 'quick --custom key=value,key1=value1'.
+    This parses the arg so that args.custom == [{'key': 'value', {'key1': 'value1'}].
+    It also supports nested maps, e.g.:
+    'quick --custom key=value,key1=nestedkey=nestevalue,nestedkey1,nestedvalue1'
+    becomes [{'key': 'value', {'key1': 'nestedkey=nestevalue,nestedkey1,nestedvalue1'}].
+    """
+
     def __call__(self, parser, namespace, values, option_string=None):
         args = {}
         if not isinstance(values, (list,)):
             values = (values,)
         for value in values:
             # only split at first '=' to allow args contain '=' as well
-            i = value.find("=")
-            n, v = value[:i], value[i + 1 :]
-            args[n] = v
+            split_index = value.find("=")
+            arg_key, arg_value = value[:split_index], value[split_index + 1 :]
+            args[arg_key] = arg_value
         setattr(namespace, self.dest, args)
